@@ -51,10 +51,7 @@ test_that("it plots the empty model as a vertical line when outcome is on Y, one
     gf_model(lm(later_anxiety ~ NULL, data = er)) %>%
     expect_doppelganger(snap_name("gf_boxplot", " -- 2"))
 
-  testthat::skip_if(
-    grepl("development", R.version.string, fixed = TRUE),
-    "These have been visually checked to be correct on R-devel, but the vdiffr fails."
-  )
+  testthat::skip_if(Sys.getenv("CI") == "true", "Skipping these tests on GitHub Actions.")
 
   gf_violin(later_anxiety ~ 1, data = er) %>%
     gf_model(lm(later_anxiety ~ NULL, data = er)) %>%
@@ -87,15 +84,8 @@ test_that("it plots the empty model as a vertical line when outcome is on X, one
     gf_model(lm(later_anxiety ~ NULL, data = er)) %>%
     expect_doppelganger(snap_name("gf_boxplot"))
 
-  # TODO: Can't find geom called "boxploth"
-  # gf_boxploth(~later_anxiety, data = er) %>%
-  #   gf_model(lm(later_anxiety ~ NULL, data = er)) %>%
-  #   expect_doppelganger(snap_name("gf_boxplot"))
 
-  testthat::skip_if(
-    grepl("development", R.version.string, fixed = TRUE),
-    "These have been visually checked to be correct on R-devel, but the vdiffr fails."
-  )
+  testthat::skip_if(Sys.getenv("CI") == "true", "Skipping these tests on GitHub Actions.")
 
   gf_violin(1 ~ later_anxiety, data = er) %>%
     gf_model(lm(later_anxiety ~ NULL, data = er)) %>%
@@ -118,10 +108,7 @@ test_that("it plots the empty model as a vertical line when outcome is on X, one
 # Single predictor, on axis, categorical ------------------------------------------------------
 
 test_that("it plots 1 predictor (on axis, categorical) models as lines at means, outcome on Y", {
-  testthat::skip_if(
-    grepl("development", R.version.string, fixed = TRUE),
-    "These have been visually checked to be correct on R-devel, but the vdiffr fails."
-  )
+  testthat::skip_if(Sys.getenv("CI") == "true", "Skipping these tests on GitHub Actions.")
 
   snap_name <- function(plot_name, suffix = "") {
     glue("[{plot_name}] cond. mod., outcome on Y{suffix}")
@@ -141,7 +128,6 @@ test_that("it plots 1 predictor (on axis, categorical) models as lines at means,
     glue("[{plot_name}] cond. mod., outcome on X{suffix}")
   }
 
-  # TODO: Can't find geom called "boxploth"
   plot_args <- list(gformula = condition ~ later_anxiety, color = ~condition, data = er)
   plot_types <- c("gf_point")
   purrr::walk(plot_types, function(plot) {
@@ -155,10 +141,7 @@ test_that("it plots 1 predictor (on axis, categorical) models as lines at means,
 # Single predictor, on aesthetic, categorical -------------------------------------------------
 
 test_that("it plots 1 predictor (on aesthetic, cat.) models as lines at means, outcome on Y", {
-  testthat::skip_if(
-    grepl("development", R.version.string, fixed = TRUE),
-    "These have been visually checked to be correct on R-devel, but the vdiffr fails."
-  )
+  testthat::skip_if(Sys.getenv("CI") == "true", "Skipping these tests on GitHub Actions.")
 
   snap_name <- function(plot_name, suffix = "") {
     glue("[{plot_name}] cond. mod., outcome on Y, pred. on color")
@@ -174,7 +157,6 @@ test_that("it plots 1 predictor (on aesthetic, cat.) models as lines at means, o
   })
 
   # plot where one axis is calculated
-  # TODO: skip "gf_histogramh", "gf_dhistogramh" funs because their related stat funs can't be found
   plot_args <- list(gformula = ~later_anxiety, color = ~condition, data = er)
   plot_types <- c("gf_rugy")
   purrr::walk(plot_types, function(plot) {
@@ -185,10 +167,7 @@ test_that("it plots 1 predictor (on aesthetic, cat.) models as lines at means, o
 })
 
 test_that("it plots 1 predictor (on aesthetic, cat.) models as lines at means, outcome on X", {
-  testthat::skip_if(
-    grepl("development", R.version.string, fixed = TRUE),
-    "These have been visually checked to be correct on R-devel, but the vdiffr fails."
-  )
+  testthat::skip_if(Sys.getenv("CI") == "true", "Skipping these tests on GitHub Actions.")
 
   snap_name <- function(plot_name, suffix = "") {
     glue("[{plot_name}] cond. mod., outcome on X, pred. on color")
@@ -217,10 +196,7 @@ test_that("it plots 1 predictor (on aesthetic, cat.) models as lines at means, o
 # Single predictor, on facet, categorical -----------------------------------------------------
 
 test_that("it plots 1 predictor (on facet, compact cat.) models as lines at means, outcome on Y", {
-  testthat::skip_if(
-    grepl("development", R.version.string, fixed = TRUE),
-    "These have been visually checked to be correct on R-devel, but the vdiffr fails."
-  )
+  testthat::skip_if(Sys.getenv("CI") == "true", "Skipping these tests on GitHub Actions.")
 
   snap_name <- function(plot_name, suffix = "") {
     glue("[{plot_name}] cond. mod., outcome on Y, pred. on facet")
@@ -257,10 +233,7 @@ test_that("it plots 1 predictor (on facet, compact cat.) models as lines at mean
 })
 
 test_that("it plots 1 predictor (on facet, compact cat.) models as lines at means, outcome on X", {
-  testthat::skip_if(
-    grepl("development", R.version.string, fixed = TRUE),
-    "These have been visually checked to be correct on R-devel, but the vdiffr fails."
-  )
+  testthat::skip_if(Sys.getenv("CI") == "true", "Skipping these tests on GitHub Actions.")
 
   snap_name <- function(plot_name, suffix = "") {
     glue("[{plot_name}] cond. mod., outcome on X, pred. on facet")
